﻿// Copyright © Microsoft Corporation.  All Rights Reserved.
// This code released under the terms of the 
// Microsoft Public License (MS-PL, http://opensource.org/licenses/ms-pl.html.)

namespace Microsoft.Expression.Prototyping.Mockups
{
	using System;
	using System.Windows;
	using System.Windows.Controls.Primitives;
	using System.Windows.Media;

	public class ToggleButtonWithIconMockup : ToggleButton
	{
		public Double IconSize
		{
			get { return (Double)GetValue(IconSizeProperty); }
			set { SetValue(IconSizeProperty, value); }
		}

		public static readonly DependencyProperty IconSizeProperty = DependencyProperty.Register("IconSize", typeof(Double), typeof(ToggleButtonWithIconMockup), new PropertyMetadata(16.0, null));

		public Brush IconStroke
		{
			get { return (Brush)GetValue(IconStrokeProperty); }
			set { SetValue(IconStrokeProperty, value); }
		}

		public static readonly DependencyProperty IconStrokeProperty = DependencyProperty.Register("IconStroke", typeof(Brush), typeof(ToggleButtonWithIconMockup), null);

		public Brush IconFill
		{
			get { return (Brush)GetValue(IconFillProperty); }
			set { SetValue(IconFillProperty, value); }
		}

		public static readonly DependencyProperty IconFillProperty = DependencyProperty.Register("IconFill", typeof(Brush), typeof(ToggleButtonWithIconMockup), null);

		public static readonly DependencyProperty IconImageProperty = DependencyProperty.Register("IconImage", typeof(IconImage), typeof(ToggleButtonWithIconMockup), new PropertyMetadata(IconImage.Star));

		public IconImage IconImage
		{
			get { return (IconImage)this.GetValue(IconImageProperty); }
			set { this.SetValue(IconImageProperty, value); }
		}

		public static readonly DependencyProperty IconPlacementProperty = DependencyProperty.Register("IconPlacement", typeof(IconPlacement), typeof(ToggleButtonWithIconMockup), new PropertyMetadata(IconPlacement.Left, new PropertyChangedCallback(IconPlacementChanged)));

		public IconPlacement IconPlacement
		{
			get { return (IconPlacement)this.GetValue(IconPlacementProperty); }
			set { this.SetValue(IconPlacementProperty, value); }
		}

		private static void IconPlacementChanged(DependencyObject sender, DependencyPropertyChangedEventArgs e)
		{
			((ToggleButtonWithIconMockup)sender).OnIconPlacementChanged(e);
		}

		protected virtual void OnIconPlacementChanged(DependencyPropertyChangedEventArgs e)
		{
			VisualStateManager.GoToState(this, this.IconPlacement.ToString(), true);
		}

		public ToggleButtonWithIconMockup()
		{
			base.DefaultStyleKey = typeof(ToggleButtonWithIconMockup);
		}

		public override void OnApplyTemplate()
		{
			base.OnApplyTemplate();
			VisualStateManager.GoToState(this, Enum.GetName(typeof(IconPlacement), this.IconPlacement), false);
		}
	}
}